@@ -1559,7 +1559,7 @@ void ScanJob::run()
     {
         return;
     }
-    qCWarning(LOKALIZE_LOG)<<"scan job started for"<<m_filePath<<m_dbName<<stop<<m_dbName;
+    qCDebug(LOKALIZE_LOG)<<"scan job started for"<<m_filePath<<m_dbName<<stop<<m_dbName;
     //QThread::currentThread()->setPriority(QThread::IdlePriority);
     QTime a;a.start();
 
@@ -1941,7 +1941,7 @@ ImportTmxJob::ImportTmxJob(const QString& filename, const QString& dbName)
 
 ImportTmxJob::~ImportTmxJob()
 {
-    qCWarning(LOKALIZE_LOG) <<"ImportTmxJob dtor";
+    qCDebug(LOKALIZE_LOG) <<"ImportTmxJob dtor";
 }
 
 void ImportTmxJob::run()
